﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright company="DHGMS Solutions" file="Boolean.cs">
//   2004-2012 DHGMS Solutions. Some Rights Reserved. Licensed under GNU General Public License version 2 (GPLv2)
// </copyright>
// <summary>
//   Helpers for the Boolean Data Type
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Dhgms.DataManager.Model.Helper
{
    using System;
    using System.Linq;

    /// <summary>
    /// Helpers for the Boolean Data Type
    /// </summary>
    public static class BooleanExtensions
    {
        private static readonly string[] NoValues = new[] { "N", "No", "False" };
        private static readonly string[] YesValues = new[] { "Y", "Yes", "True" };

        #region Public Methods and Operators

        /// <summary>
        /// Parses a Yes\No field into a boolean
        /// </summary>
        /// <param name="value">
        /// the value to parse
        /// </param>
        /// <returns>
        /// true \ false
        /// </returns>
        public static bool ParseYesNo(
            // this System.Boolean input,
            string value)
        {
            if (value == null)
            {
                throw new ArgumentNullException("value");
            }

            if (YesValues.Any(x => x.Equals(value, StringComparison.OrdinalIgnoreCase)))
            {
                return true;
            }

            if (NoValues.Any(x => x.Equals(value, StringComparison.OrdinalIgnoreCase)))
            {
                return false;
            }

            throw new ArgumentOutOfRangeException("value");
        }

        #endregion
    }
}